@@ -186,6 +186,7 @@ nationalities = {
     'SR': ('surinamais', 'surinamaise'),
     'SS': ('sud-soudanais', 'sud-soudanaise'),
     'ST': ('santoméen', 'santoméenne'),
+    'SU': ('soviétique', 'soviétique'),
     'SV': ('salvadorien', 'salvadorienne'),
     'SY': ('syrien', 'syrienne'),
     'SZ': ('swazi', 'swazie'),
@@ -310,6 +311,7 @@ countries = {
     'Guinée-Bissau': 'GW',
     'Guyana': 'GY',
     'Hong Kong': 'HK',
+    'Hong-Kong': 'HK',
     'Honduras': 'HN',
     'Croatie': 'HR',
     'Haïti': 'HT',
@@ -423,12 +425,13 @@ countries = {
     'Tanzanie': 'TZ',
     'Ukraine': 'UA',
     'Ouganda': 'UG',
+    'U.R.S.S.': 'SU',
     'U.S.A.': 'US',  # modified based on allociné value, originally 'États-unis'
     'Uruguay': 'UY',
     'Ouzbékistan': 'UZ',
     'Saint-Vincent-et-les Grenadines': 'VC',
     'Venezuela': 'VE',
-    'Îles Vierges (britanniques)': 'vg',
+    'Îles Vierges (britanniques)': 'VG',
     'Îles Vierges': 'VI',
     'Viêtnam': 'VN',
     'Vanuatu': 'VU',
